Skip to contents

Creates a lookup table containing burden estimates for synthetic agents based on age, sex, mental health status and disorder profiles.

Usage

make_burden_lookup(
  data_tb,
  agents_dt,
  contingency_dts_ls,
  ages_chr = c("AgeGroup10", "AgeGroup9"),
  denominator_1L_dbl = 1000,
  diseases_chr = c("Anxiety disorders", "Depressive disorders", "Alcohol use disorders"),
  disorder_conditions_chr = c("MentalHealthCondition", "SEXP", "AgeGroup9"),
  disorder_data_1L_chr = "disorders_ls",
  logic_vals_chr = c("Yes", "No"),
  output_1L_chr = c("tibble", "data.table"),
  parent_conditions_chr = c("AgeGroup4", "SEXP"),
  parent_1L_chr = "MentalHealthCondition",
  parent_data_1L_chr = "wa_sa3s_mh_dt",
  sex_1L_chr = "SEXP"
)

Arguments

data_tb

Burden-of-disease dataset.

agents_dt

Synthetic agent population.

contingency_dts_ls

Named list of contingency tables required for burden estimation.

ages_chr

Character vector specifying:

  • A burden age grouping variable.

  • A prevalence age grouping variable.

denominator_1L_dbl

Scaling factor used when converting prevalence values into burden estimates. Defaults to 1000.

diseases_chr

Character vector of diseases to include.

disorder_conditions_chr

Variables used when estimating disorder prevalence.

disorder_data_1L_chr

Name of the contingency-table list element containing disorder prevalence information.

logic_vals_chr

Labels for positive and negative condition states.

output_1L_chr

Output type. One of "tibble" or "data.table".

parent_conditions_chr

Variables used when allocating the parent mental health condition.

parent_1L_chr

Name of the parent condition variable.

parent_data_1L_chr

Name of the contingency-table list element containing parent condition information.

sex_1L_chr

Name of the sex variable.

Value

A burden lookup table containing estimated burden values for combinations of demographic and disorder characteristics.

Details

The function combines burden-of-disease rates with synthetic population distributions and disorder prevalence estimates to derive burden values that can subsequently be assigned to synthetic agents.

Burden estimates are calculated separately for combinations of mental health condition status, age group, sex and disorder categories.

Examples

if (FALSE) { # \dontrun{
burden_dt <- make_burden_lookup(
  data_tb = aus_bod_tb,
  agents_dt = agents_dt,
  contingency_dts_ls = contingency_dts_ls,
  output_1L_chr = "data.table"
)
} # }