Creates a faceted comparison of observed and expected percentages from a validation result.
Arguments
- validation_result
A validation object returned by
validate_synthetic_population_fitor stored in thevalidation_resultsslot of aReplicaAdder.
Creates a faceted comparison of observed and expected percentages from a validation result.
A validation object returned by
validate_synthetic_population_fit or stored in
the validation_results slot of a
ReplicaAdder.