Skip to contents

Creates a heatmap showing percentage-point differences between observed and expected distributions across conditioning groups.

Usage

plot_validation_heatmap(validation_results, ...)

Arguments

validation_results

Validation results generated by ratify or returned by validate_synthetic_population_fit.

These results are typically retrieved using:


procure(
  ADDER,
  slot = "validation_results"
)
...

Additional arguments.

Value

A ggplot object.

Examples

if (FALSE) { # \dontrun{
plot_validation_heatmap(
  procure(
    ADDER,
    slot = "validation_results"
  )
)
} # }