Creates lookup tables linking Australian Statistical Geography Standard (ASGS) regions across multiple levels such as SA2, SA3, SA4 and State/Territory.
Details
The function derives geographic hierarchies from spatial datasets and optionally creates higher-level region codes by substring extraction.
Examples
if (FALSE) { # \dontrun{
make_areas_lookup(
data_tb,
coding_ls = list(
STE = 1,
SA4 = 1:3,
SA3 = 1:5,
SA2 = 1:9
)
)
} # }